@@ -5,6 +5,7 @@
 # Visit https://aboutcode.org and https://github.com/nexB/univers for support and download.
 
 from functools import total_ordering
+import functools
 
 import attr
 import semantic_version
@@ -13,6 +14,7 @@ from packaging import version as packaging_version
 from univers import arch
 from univers import debian
 from univers import gem
+from univers import nuget
 from univers import gentoo
 from univers import maven
 from univers import rpm
@@ -284,10 +286,32 @@ class MavenVersion(Version):
         return maven.Version(string)
 
 
+# We will use total ordering to sort the versions, since these versions also consider prereleases.
 @attr.s(frozen=True, order=False, eq=False, hash=True)
-class NugetVersion(SemverVersion):
+@functools.total_ordering
+class NugetVersion(Version):
     # See https://docs.microsoft.com/en-us/nuget/concepts/package-versioning
-    pass
+
+    @classmethod
+    def build_value(cls, string):
+        return nuget.Version.from_string(string)
+
+    @classmethod
+    def is_valid(cls, string):
+        try:
+            cls.build_value(string)
+            return True
+        except ValueError:
+            return False
+
+    def __str__(self):
+        return str(self.string)
+
+    def __lt__(self, other):
+        return nuget.Version.from_string(self.string) < nuget.Version.from_string(other.string)
+
+    def __eq__(self, other):
+        return nuget.Version.from_string(self.string) == nuget.Version.from_string(other.string)
 
 
 @attr.s(frozen=True, order=False, eq=False, hash=True)
@@ -363,6 +387,19 @@ class LegacyOpensslVersion(Version):
     univers.versions.InvalidVersion: '3.0.2' is not a valid <class 'univers.versions.LegacyOpensslVersion'>
     """
 
+    major = attr.ib(type=int, default=None, repr=False)
+    minor = attr.ib(type=int, default=None, repr=False)
+    build = attr.ib(type=int, default=None, repr=False)
+    patch = attr.ib(type=str, default=None, repr=False)
+
+    def __attrs_post_init__(self):
+        super().__attrs_post_init__()
+        major, minor, build, patch = self.value
+        object.__setattr__(self, "major", major)
+        object.__setattr__(self, "minor", minor)
+        object.__setattr__(self, "build", build)
+        object.__setattr__(self, "patch", patch)
+
     @classmethod
     def is_valid(cls, string):
         return bool(cls.parse(string))
@@ -423,7 +460,29 @@ class LegacyOpensslVersion(Version):
         return cls.parse(string)
 
     def __str__(self):
-        return f"{self.value[0]}.{self.value[1]}.{self.value[2]}{self.value[3]}"
+        return f"{self.major}.{self.minor}.{self.build}{self.patch}"
+
+    def __lt__(self, other):
+        if not isinstance(other, self.__class__):
+            return NotImplemented
+        # Check if versions have the same base, and `one and only one` of them is a pre-release.
+        if (self.major, self.minor, self.build) == (other.major, other.minor, other.build) and (
+            self.is_prerelease() != other.is_prerelease()
+        ):
+            return self.is_prerelease()
+        return self.value.__lt__(other.value)
+
+    def __gt__(self, other):
+        if not isinstance(other, self.__class__):
+            return NotImplemented
+        if (self.major, self.minor, self.build) == (other.major, other.minor, other.build) and (
+            self.is_prerelease() != other.is_prerelease()
+        ):
+            return other.is_prerelease()
+        return self.value.__gt__(other.value)
+
+    def is_prerelease(self):
+        return self.patch.startswith(("-beta", "-alpha"))
 
 
 @attr.s(frozen=True, order=False, eq=False, hash=True)
